==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/hu-HU/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'A tömeges törlési eszközök megerősítése',
    'bulk_restore'      => 'Az eszközök tömeges helyreállításának megerősítése', 
  'bulk_delete_help'	=> 'Tömeges törléshez tekintse át az eszközöket. Ha törli az eszközöket, azok visszaállíthatók, de többé nem lesznek hozzárendelve a korábban hozzárendelt felhasználókhoz.',
  'bulk_restore_help'	=> 'Tekintse át az alábbi eszközöket a tömeges helyreállításhoz. A visszaállítás után ezek az eszközök nem lesznek társítva a korábban hozzárendelt felhasználókhoz.',
  'bulk_delete_warn'	=> 'Le akarod törölni a :asset_count eszközt.',
  'bulk_restore_warn'	=> 'Vissza készül állítani :asset_count eszközt.',
    'bulk_update'		=> 'Tömeges eszköz frissítés',
    'bulk_update_help'	=> 'Ez az űrlap segít frissíteni több eszközt egyszerre. Csak töltsd ki a változtatni kívánt mezőket. Mindent amit üresen hagysz az változatlan marad. ',
    'bulk_update_warn'	=> 'Egyetlen eszköz tulajdonságait kívánja szerkeszteni.|:asset_count eszköz tulajdonságait kívánja szerkeszteni.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'Ezeken a modelleken', 
    'bulk_update_custom_field_unique' => 'Ez egy egyedi mező és nem lehet tömegesen módosítani.',
    'checkedout_to'		=> 'Kiadva',
    'checkout_date'		=> 'Kiadási dátum',
    'checkin_date'		=> 'Visszavétel dátuma',
    'checkout_to'		=> 'Kiadva',
    'cost'				=> 'Beszerzési érték',
    'create'			=> 'Eszköz létrehozása',
    'date'				=> 'Vásárlás dátuma',
    'depreciation'	    => 'Értékcsökkenés',
    'depreciates_on'	=> 'Leértékelődik',
    'default_location'	=> 'Alapértelmezett hely',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Lejárat Dátuma',
    'eol_rate'			=> 'EOL arány',
    'expected_checkin'  => 'Várható visszaadás dátuma',
    'expires'			=> 'Lejárat',
    'fully_depreciated'	=> 'Teljesen értékcsökkentett',
    'help_checkout'		=> 'Ha azonnal kiadná ezt az eszközt, válassza a "Kiadásra készen" státuszt a fenti listából. ',
    'mac_address'		=> 'MAC-cím',
    'manufacturer'		=> 'Gyártó',
    'model'				=> 'Modell',
    'months'			=> 'hónapok',
    'name'				=> 'Eszköz neve',
    'notes'				=> 'Megjegyzések',
    'order'				=> 'Számla sorszáma',
    'qr'				=> 'QR Code',
    'requestable'		=> 'A felhasználók kérhetik ezt az eszközt',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Állapot típusának kiválasztása',
    'serial'			=> 'Sorozatszám',
    'status'			=> 'Státusz',
    'tag'				=> 'Eszköz azonosító',
    'update'			=> 'Eszköz frissítés',
    'warranty'			=> 'Garancia',
        'warranty_expires'		=> 'Jótállás érvényessége',
    'years'				=> 'évek',
    'asset_location' => 'Eszköz helyszín frissítése',
    'asset_location_update_default_current' => 'Alapértelmezett helyszín és aktuális helyszín frissítése',
    'asset_location_update_default' => 'Csak az alapértelmezett helyszín frissítése',
    'asset_location_update_actual' => 'Csak az aktuális helyszín frissítése',
    'asset_not_deployable' => 'Az eszköz még nem kiadásra kész, még nem kiadható.',
    'asset_deployable' => 'Az eszköz kiadásra kész, kiadható.',
    'processing_spinner' => 'Feldolgozás folyamatban... (Nagyméretű fájlok esetében ez eltarthat egy darabig)',
    'optional_infos'  => 'Nem kötelező információk',
    'order_details'   => 'Megrendeléssel kapcsolatos információk'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/hu-HU/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'A tömeges törlési eszközök megerősítése',
    'bulk_restore'      => 'Az eszközök tömeges helyreállításának megerősítése', 
  'bulk_delete_help'	=> 'Tömeges törléshez tekintse át az eszközöket. Ha törli az eszközöket, azok visszaállíthatók, de többé nem lesznek hozzárendelve a korábban hozzárendelt felhasználókhoz.',
  'bulk_restore_help'	=> 'Tekintse át az alábbi eszközöket a tömeges helyreállításhoz. A visszaállítás után ezek az eszközök nem lesznek társítva a korábban hozzárendelt felhasználókhoz.',
  'bulk_delete_warn'	=> 'Le akarod törölni a :asset_count eszközt.',
  'bulk_restore_warn'	=> 'Vissza készül állítani :asset_count eszközt.',
    'bulk_update'		=> 'Tömeges eszköz frissítés',
    'bulk_update_help'	=> 'Ez az űrlap segít frissíteni több eszközt egyszerre. Csak töltsd ki a változtatni kívánt mezőket. Mindent amit üresen hagysz az változatlan marad. ',
    'bulk_update_warn'	=> 'Egyetlen eszköz tulajdonságait kívánja szerkeszteni.|:asset_count eszköz tulajdonságait kívánja szerkeszteni.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'Ezeken a modelleken', 
    'bulk_update_custom_field_unique' => 'Ez egy egyedi mező és nem lehet tömegesen módosítani.',
    'checkedout_to'		=> 'Kiadva',
    'checkout_date'		=> 'Kiadási dátum',
    'checkin_date'		=> 'Visszavétel dátuma',
    'checkout_to'		=> 'Kiadva',
    'cost'				=> 'Beszerzési érték',
    'create'			=> 'Eszköz létrehozása',
    'date'				=> 'Vásárlás dátuma',
    'depreciation'	    => 'Értékcsökkenés',
    'depreciates_on'	=> 'Leértékelődik',
    'default_location'	=> 'Alapértelmezett hely',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Lejárat Dátuma',
    'eol_rate'			=> 'EOL arány',
    'expected_checkin'  => 'Várható visszaadás dátuma',
    'expires'			=> 'Lejárat',
    'fully_depreciated'	=> 'Teljesen értékcsökkentett',
    'help_checkout'		=> 'Ha azonnal kiadná ezt az eszközt, válassza a "Kiadásra készen" státuszt a fenti listából. ',
    'mac_address'		=> 'MAC-cím',
    'manufacturer'		=> 'Gyártó',
    'model'				=> 'Modell',
    'months'			=> 'hónapok',
    'name'				=> 'Eszköz neve',
    'notes'				=> 'Megjegyzések',
    'order'				=> 'Számla sorszáma',
    'qr'				=> 'QR Code',
    'requestable'		=> 'A felhasználók kérhetik ezt az eszközt',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Állapot típusának kiválasztása',
    'serial'			=> 'Sorozatszám',
    'status'			=> 'Státusz',
    'tag'				=> 'Eszköz azonosító',
    'update'			=> 'Eszköz frissítés',
    'warranty'			=> 'Garancia',
        'warranty_expires'		=> 'Jótállás érvényessége',
    'years'				=> 'évek',
    'asset_location' => 'Eszköz helyszín frissítése',
    'asset_location_update_default_current' => 'Alapértelmezett helyszín és aktuális helyszín frissítése',
    'asset_location_update_default' => 'Csak az alapértelmezett helyszín frissítése',
    'asset_location_update_actual' => 'Csak az aktuális helyszín frissítése',
    'asset_not_deployable' => 'Az eszköz még nem kiadásra kész, még nem kiadható.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Az eszköz kiadásra kész, kiadható.',
    'processing_spinner' => 'Feldolgozás folyamatban... (Nagyméretű fájlok esetében ez eltarthat egy darabig)',
    'optional_infos'  => 'Nem kötelező információk',
    'order_details'   => 'Megrendeléssel kapcsolatos információk'
];
